/* ESP8266_WS_bmp280

   Create A Simple ESP8266 Weather Station With BME280
    https://lastminuteengineers.com/bme280-esp8266-weather-station/

    Az alábbi program már a cikk végán említett kiegészítéseket is tartalmazza:
    - SVG grafikus ikonok
    - Stilizált kiírás
    - AJAX push script

    Megjegyzés: a Google font elérése globális Internetelérést feltételez
    Ha ez nem áll rendelkezésre, akkor hagyjuk ki a 83. sort, amelyben ez áll:
    ptr += "<link href='https://fonts.googleapis.com/css?family=Open+Sans:300,400,600' rel='stylesheet'>";
*/

#include <ESP8266WebServer.h>
#include <FS.h>   //Include File System Headers
#include <ArduinoJson.h>
#include "secrets.h"
#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BME280.h>

#define SEALEVELPRESSURE_HPA (1013.25)

Adafruit_BME280 bme;

float temperature, humidity, pressure, altitude;

ESP8266WebServer server(80);
StaticJsonDocument<200> doc;

void setup_wifi() {
  Serial.begin(115200);
  WiFi.mode(WIFI_STA);
  WiFi.begin(WIFI_SSID, WIFI_PASS);
  Serial.print("Connecting to ");
  Serial.print(WIFI_SSID);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println();
  Serial.print("Connected! IP address: ");
  Serial.println(WiFi.localIP());
}


void setup() {
  setup_wifi();
  bme.begin(0x76);
  if (SPIFFS.begin()) {
    Serial.println("SPIFFS Mount succesfull");
  } else {
    Serial.println("SPIFFS Mount failed");
  }
  server.on("/readBME280", handle_BME280);              // Serve AJAX requests
  server.onNotFound(handle_NotFound);                   // If the client requests any other URI
  server.begin();
  Serial.println("HTTP server started");
}

void loop() {
  server.handleClient();
}

void handle_BME280() {
  doc["temperature"] = String(bme.readTemperature(), 1);
  doc["humidity"] = (int)bme.readHumidity();
  doc["pressure"] = String(((bme.readPressure() + 1440) / 100.0F), 1);
  doc["altitude"] = (int)bme.readAltitude(SEALEVELPRESSURE_HPA);
  Serial.println(doc.as<String>());
  server.send(200, "application/json", doc.as<String>());
}

void handle_NotFound() {
  if (!handleFileRead(server.uri()))                    // send requested file if it exists
    server.send(404, "text/plain", "404: Not Found");   // otherwise, respond with a 404 (Not Found) error
}

bool handleFileRead(String path) {                      // send the right file to the client (if it exists)
  Serial.println("handleFileRead: " + path);
  if (path.endsWith("/")) path += "index.html";         // If a folder is requested, send the index file
  String contentType = getContentType(path);            // Get the MIME type
  if (SPIFFS.exists(path)) {                            // If the file exists
    File file = SPIFFS.open(path, "r");                 // Open it
    size_t sent = server.streamFile(file, contentType); // And send it to the client
    file.close(); // Then close the file again
    return true;
  } else {
    Serial.println("\tFile Not Found");
    return false;                                       // If the file doesn't exist, return false
  }
}

String getContentType(String filename){
  if(filename.endsWith(".htm")) return "text/html";
  else if(filename.endsWith(".html")) return "text/html";
  else if(filename.endsWith(".css")) return "text/css";
  else if(filename.endsWith(".js")) return "application/javascript";
  else if(filename.endsWith(".png")) return "image/png";
  else if(filename.endsWith(".gif")) return "image/gif";
  else if(filename.endsWith(".jpg")) return "image/jpeg";
  else if(filename.endsWith(".ico")) return "image/x-icon";
  else if(filename.endsWith(".svg")) return "image/svg+xml";  
  else if(filename.endsWith(".xml")) return "text/xml";
  else if(filename.endsWith(".json")) return "application/json";  
  else if(filename.endsWith(".pdf")) return "application/x-pdf";
  else if(filename.endsWith(".zip")) return "application/x-zip";
  else if(filename.endsWith(".gz")) return "application/x-gzip";
  return "text/plain";
}
